@@ -377,51 +377,72 @@ static gchar *
 get_filename (ChamplainNetworkMapSource *source,
     ChamplainTile *tile)
 {
+#ifdef USE_MAEMO
+  return g_strdup_printf ("/home/user/MyDocs/.maps" G_DIR_SEPARATOR_S
+             "%s" G_DIR_SEPARATOR_S "%d" G_DIR_SEPARATOR_S
+             "%d" G_DIR_SEPARATOR_S "%d.png",
+             champlain_map_source_get_id (CHAMPLAIN_MAP_SOURCE (source)),
+             champlain_tile_get_zoom_level (tile),
+             champlain_tile_get_x (tile), champlain_tile_get_y (tile));
+#else
   return g_strdup_printf ("%s" G_DIR_SEPARATOR_S "%s" G_DIR_SEPARATOR_S
              "%s" G_DIR_SEPARATOR_S "%d" G_DIR_SEPARATOR_S
              "%d" G_DIR_SEPARATOR_S "%d.png", g_get_user_cache_dir (),
              CACHE_SUBDIR, champlain_map_source_get_id (CHAMPLAIN_MAP_SOURCE (source)),
              champlain_tile_get_zoom_level (tile),
              champlain_tile_get_x (tile), champlain_tile_get_y (tile));
+#endif
 }
 
+static ClutterActor *error_actor = NULL;
+
 static void
 create_error_tile (ChamplainTile* tile)
 {
-  ClutterActor *actor;
-  cairo_t *cr;
-  cairo_pattern_t *pat;
-  guint size;
+  ClutterActor *clone;
 
-  size = champlain_tile_get_size (tile);
-  actor = clutter_cairo_texture_new (size, size);
-  cr = clutter_cairo_texture_create (CLUTTER_CAIRO_TEXTURE (actor));
+  if (!error_actor)
+    {
+      guint size;
+      ClutterActor *actor;
+      cairo_t *cr;
+      cairo_pattern_t *pat;
+      ClutterActor *stage;
 
-  /* draw a linear gray to white pattern */
-  pat = cairo_pattern_create_linear (size / 2.0, 0.0,  size, size / 2.0);
-  cairo_pattern_add_color_stop_rgb (pat, 0, 0.686, 0.686, 0.686);
-  cairo_pattern_add_color_stop_rgb (pat, 1, 0.925, 0.925, 0.925);
-  cairo_set_source (cr, pat);
-  cairo_rectangle (cr, 0, 0, size, size);
-  cairo_fill (cr);
+      size = champlain_tile_get_size (tile);
+      actor = clutter_cairo_texture_new (size, size);
+      cr = clutter_cairo_texture_create (CLUTTER_CAIRO_TEXTURE (actor));
+      stage = clutter_stage_get_default ();
 
-  cairo_pattern_destroy (pat);
+      /* draw a linear gray to white pattern */
+      pat = cairo_pattern_create_linear (size / 2.0, 0.0,  size, size / 2.0);
+      cairo_pattern_add_color_stop_rgb (pat, 0, 0.686, 0.686, 0.686);
+      cairo_pattern_add_color_stop_rgb (pat, 1, 0.925, 0.925, 0.925);
+      cairo_set_source (cr, pat);
+      cairo_rectangle (cr, 0, 0, size, size);
+      cairo_fill (cr);
 
-  /* draw the red cross */
-  cairo_set_source_rgb (cr, 0.424, 0.078, 0.078);
-  cairo_set_line_width (cr, 14.0);
-  cairo_set_line_cap (cr, CAIRO_LINE_CAP_ROUND);
-  cairo_move_to (cr, 24, 24);
-  cairo_line_to (cr, 50, 50);
-  cairo_move_to (cr, 50, 24);
-  cairo_line_to (cr, 24, 50);
-  cairo_stroke (cr);
+      cairo_pattern_destroy (pat);
 
-  cairo_destroy (cr);
+      /* draw the red cross */
+      cairo_set_source_rgb (cr, 0.424, 0.078, 0.078);
+      cairo_set_line_width (cr, 14.0);
+      cairo_set_line_cap (cr, CAIRO_LINE_CAP_ROUND);
+      cairo_move_to (cr, 24, 24);
+      cairo_line_to (cr, 50, 50);
+      cairo_move_to (cr, 50, 24);
+      cairo_line_to (cr, 24, 50);
+      cairo_stroke (cr);
 
-  champlain_tile_set_content (tile, actor, TRUE);
-  clutter_actor_show (actor);
+      cairo_destroy (cr);
 
+      clutter_actor_show (actor);
+      clutter_container_add_actor (CLUTTER_CONTAINER (stage), actor);
+      error_actor = actor;
+    }
+
+  clone = clutter_clone_new (error_actor);
+  champlain_tile_set_content (tile, clone, TRUE);
   champlain_tile_set_state (tile, CHAMPLAIN_STATE_DONE);
 }
 
